@@ -96,9 +96,9 @@ class MuminDataset:
               Multimodal Fact-Checked Misinformation Dataset with Linked Social
               Network Posts_ (2021)
     '''
-
-    download_url: str = ('https://github.com/CLARITI-REPHRAIN/mumin-build/'
-                         'raw/main/data/mumin.zip')
+    download_url: str = ('https://github.com/CLARITI-REPHRAIN/mumin-build/raw/'
+                         '25fab15b7f27e99fca34637891f18c9927609473/'
+                         'data/mumin.zip')
     _node_dump: List[str] = ['claim', 'tweet', 'user', 'image', 'article',
                              'place', 'hashtag', 'poll', 'reply']
     _rel_dump: List[Tuple[str, str, str]] = [
@@ -164,12 +164,6 @@ class MuminDataset:
         else:
             logger.setLevel(logging.WARNING)
 
-        # Raise warning
-        warnings.warn('This dataset is currently under review. This dataset '
-                      'must not be used until this warning is removed, as the '
-                      'dataset is subject to change, for example, during the '
-                      'review period.')
-
     def __repr__(self) -> str:
         '''A string representation of the dataaset.
 
@@ -212,9 +206,13 @@ class MuminDataset:
             self._extract_images()
             self._filter_node_features()
             self._filter_relations()
-            self._remove_auxilliaries()
-            self._remove_islands()
-            self._dump_to_csv()
+
+        # Clean up dataset
+        self._remove_auxilliaries()
+        self._remove_islands()
+
+        # Store dataset
+        self._dump_to_csv()
 
         # Mark dataset as compiled
         self.compiled = True
@@ -1167,7 +1165,7 @@ class MuminDataset:
             with mp.Pool(processes=mp.cpu_count()) as pool:
                 for result in tqdm(pool.imap_unordered(process_article_url,
                                                        article_urls,
-                                                       chunksize=5),
+                                                       chunksize=50),
                                    desc='Parsing articles',
                                    total=len(article_urls)):
 
@@ -1258,7 +1256,7 @@ class MuminDataset:
             with mp.Pool(processes=mp.cpu_count()) as pool:
                 for result in tqdm(pool.imap_unordered(process_image_url,
                                                        image_urls,
-                                                       chunksize=5),
+                                                       chunksize=50),
                                    desc='Parsing images',
                                    total=len(image_urls)):
 
@@ -1465,12 +1463,12 @@ class MuminDataset:
             if text != text:
                 return None
             else:
-                return np.asarray(pipeline(text))[0, 0, :]
+                return np.asarray(pipeline(text, truncation=True))[0, 0, :]
 
         # Embed user description using the pretrained transformer
         desc_embs = self.nodes['user'].description.progress_apply(embed)
         emb_dim = desc_embs.dropna().iloc[0].shape
-        desc_embs[desc_embs.isna()] = np.zeros(emb_dim)
+        desc_embs[desc_embs.isna()] = np.zeros((len(desc_embs), emb_dim))
         self.nodes['user']['description_emb'] = desc_embs
 
         return self
@@ -1492,9 +1490,10 @@ class MuminDataset:
             def embed(text: Union[str, List[str]]):
                 '''Extract a text embedding'''
                 if isinstance(text, str):
-                    return np.asarray(pipeline(text))[0, 0, :]
+                    return np.asarray(pipeline(text, truncation=True))[0, 0, :]
                 else:
-                    arrays = [np.asarray(pipeline(doc))[0, 0, :]
+                    arrays = [np.asarray(pipeline(doc,
+                                                  truncation=True))[0, 0, :]
                               for doc in text]
                     return np.mean(arrays)
 
